@@ -294,7 +294,10 @@ var Executor = /*#__PURE__*/function () {
           errors: errors,
           operation: _this5._operation.request.node,
           variables: _this5._operation.request.variables
-        };
+        }; // In V8, Error objects keep the closure scope chain alive until the
+        // err.stack property is accessed.
+
+        error.stack;
         throw error;
       } else {
         var responseWithData = response;
@@ -435,7 +438,6 @@ var Executor = /*#__PURE__*/function () {
       var payload = normalizeResponse(response, this._operation.root, ROOT_TYPE, {
         getDataID: this._getDataID,
         path: [],
-        request: this._operation.request,
         treatMissingFieldsAsNull: treatMissingFieldsAsNull
       });
       validateOptimisticResponsePayload(payload);
@@ -506,7 +508,6 @@ var Executor = /*#__PURE__*/function () {
     }, selector, moduleImportPayload.typeName, {
       getDataID: this._getDataID,
       path: moduleImportPayload.path,
-      request: this._operation.request,
       treatMissingFieldsAsNull: this._treatMissingFieldsAsNull
     });
   };
@@ -575,8 +576,7 @@ var Executor = /*#__PURE__*/function () {
       var relayPayload = normalizeResponse(payloadPart, _this8._operation.root, ROOT_TYPE, {
         getDataID: _this8._getDataID,
         treatMissingFieldsAsNull: _this8._treatMissingFieldsAsNull,
-        path: [],
-        request: _this8._operation.request
+        path: []
       });
 
       _this8._publishQueue.commitPayload(_this8._operation, relayPayload, _this8._updater);
@@ -681,11 +681,9 @@ var Executor = /*#__PURE__*/function () {
     if (syncOperation != null) {
       // If the operation module is available synchronously, normalize the
       // data synchronously.
-      this._schedule(function () {
-        _this10._handleModuleImportPayload(moduleImportPayload, syncOperation);
+      this._handleModuleImportPayload(moduleImportPayload, syncOperation);
 
-        _this10._maybeCompleteSubscriptionOperationTracking();
-      });
+      this._maybeCompleteSubscriptionOperationTracking();
     } else {
       // Otherwise load the operation module and schedule a task to normalize
       // the data when the module is available.
@@ -753,8 +751,6 @@ var Executor = /*#__PURE__*/function () {
   ;
 
   _proto._processIncrementalPlaceholder = function _processIncrementalPlaceholder(relayPayload, placeholder) {
-    var _this11 = this;
-
     var _relayPayload$fieldPa;
 
     // Update the label => path => placeholder map
@@ -834,15 +830,13 @@ var Executor = /*#__PURE__*/function () {
 
 
     if (pendingResponses != null) {
-      this._schedule(function () {
-        var payloadFollowups = _this11._processIncrementalResponses(pendingResponses);
+      var payloadFollowups = this._processIncrementalResponses(pendingResponses);
 
-        var updatedOwners = _this11._publishQueue.run();
+      var updatedOwners = this._publishQueue.run();
 
-        _this11._updateOperationTracker(updatedOwners);
+      this._updateOperationTracker(updatedOwners);
 
-        _this11._processPayloadFollowups(payloadFollowups);
-      });
+      this._processPayloadFollowups(payloadFollowups);
     }
   }
   /**
@@ -853,7 +847,7 @@ var Executor = /*#__PURE__*/function () {
   ;
 
   _proto._processIncrementalResponses = function _processIncrementalResponses(incrementalResponses) {
-    var _this12 = this;
+    var _this11 = this;
 
     var relayPayloads = [];
     incrementalResponses.forEach(function (incrementalResponse) {
@@ -861,12 +855,12 @@ var Executor = /*#__PURE__*/function () {
           path = incrementalResponse.path,
           response = incrementalResponse.response;
 
-      var resultForLabel = _this12._incrementalResults.get(label);
+      var resultForLabel = _this11._incrementalResults.get(label);
 
       if (resultForLabel == null) {
         resultForLabel = new Map();
 
-        _this12._incrementalResults.set(label, resultForLabel);
+        _this11._incrementalResults.set(label, resultForLabel);
       }
 
       if (label.indexOf('$defer$') !== -1) {
@@ -887,7 +881,7 @@ var Executor = /*#__PURE__*/function () {
 
         var placeholder = resultForPath.placeholder;
         !(placeholder.kind === 'defer') ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayModernEnvironment: Expected data for path `%s` for label `%s` ' + 'to be data for @defer, was `@%s`.', pathKey, label, placeholder.kind) : invariant(false) : void 0;
-        relayPayloads.push(_this12._processDeferResponse(label, path, placeholder, response));
+        relayPayloads.push(_this11._processDeferResponse(label, path, placeholder, response));
       } else {
         // @stream payload path values end in the field name and item index,
         // but Relay records paths relative to the parent of the stream node:
@@ -912,7 +906,7 @@ var Executor = /*#__PURE__*/function () {
 
         var _placeholder = _resultForPath.placeholder;
         !(_placeholder.kind === 'stream') ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayModernEnvironment: Expected data for path `%s` for label `%s` ' + 'to be data for @stream, was `@%s`.', _pathKey, label, _placeholder.kind) : invariant(false) : void 0;
-        relayPayloads.push(_this12._processStreamResponse(label, path, _placeholder, response));
+        relayPayloads.push(_this11._processStreamResponse(label, path, _placeholder, response));
       }
     });
     return relayPayloads;
@@ -923,7 +917,6 @@ var Executor = /*#__PURE__*/function () {
     var relayPayload = normalizeResponse(response, placeholder.selector, placeholder.typeName, {
       getDataID: this._getDataID,
       path: placeholder.path,
-      request: this._operation.request,
       treatMissingFieldsAsNull: this._treatMissingFieldsAsNull
     });
 
@@ -1075,7 +1068,6 @@ var Executor = /*#__PURE__*/function () {
     var relayPayload = normalizeResponse(response, selector, typeName, {
       getDataID: this._getDataID,
       path: [].concat((0, _toConsumableArray2["default"])(normalizationPath), [responseKey, String(itemIndex)]),
-      request: this._operation.request,
       treatMissingFieldsAsNull: this._treatMissingFieldsAsNull
     });
     return {
